@@ -1,3 +1,3 @@
-from tools import load_png, load_fnt, get_text_map, load_font
+from .tools import load_png, load_fnt, get_text_map, load_font
 
 __all__ = ["load_png", "load_fnt", "get_text_map", "load_font"]
\ No newline at end of file
