@@ -5,16 +5,15 @@ import time
 import timeit
 import numpy as np
 import numpy.random as rdn
-from qtools.qtpy import QtCore, QtGui
-from qtools.qtpy.QtCore import Qt, pyqtSignal
-from qtools import show_window
+from qtop.qtpy import QtCore, QtGui
+from qtop.qtpy.QtCore import Qt, pyqtSignal
+from qtop import show_window
 from analyst import DEBUG, log_debug, log_info, log_warn
 try:
-    from qtools.qtpy.QtOpenGL import QGLWidget, QGLFormat
+    from qtop.qtpy.QtOpenGL import QGLWidget, QGLFormat
 except Exception as e:
     log_warn((("The Qt-OpenGL bindings are not available. "
-    "On Ubuntu, please install python-qt4-gl (PyQt4) or "
-    "python-pyside.qtopengl (PySide). "
+    "On Ubuntu, please install python3-qt5. "
     "Original exception was: %s" % e)))
 
     class QGLWidget(QtGui.QWidget):
